@@ -178,7 +178,7 @@ bool OptionsHandler::handle_options(vector<string>& LongOptions, string& ShortOp
                 to_compute.set(ConeProperty::HilbertBasis);
                 break;
             case 'w':
-                to_compute.set(ConeProperty::IsIntegrallyClosed);
+                to_compute.set(ConeProperty::WitnessNotIntegrallyClosed);
                 break;
             case '1':
                 to_compute.set(ConeProperty::Deg1Elements);
@@ -378,7 +378,10 @@ void OptionsHandler::applyOutputOptions(Output<Integer>& Out) {
     else if (write_extra_files) {
         Out.set_write_extra_files();
     }
-    if (to_compute.test(ConeProperty::Triangulation) || to_compute.test(ConeProperty::ConeDecomposition)) {
+    if (to_compute.test(ConeProperty::Triangulation) || to_compute.test(ConeProperty::ConeDecomposition)
+        || to_compute.test(ConeProperty::UnimodularTriangulation) || to_compute.test(ConeProperty::LatticePointTriangulation) 
+        || to_compute.test(ConeProperty::AllGeneratorsTriangulation)
+    ) {
         Out.set_write_tri(true);
         Out.set_write_tgn(true);
         Out.set_write_inv(true);
@@ -478,4 +481,4 @@ string pureName(const string& fullName) {
     // cout << "**************************** " << fullName.substr(found,length) << endl;
     // exit(1);
     return (fullName.substr(found, length));
-}
\ No newline at end of file
+}
